@@ -1718,10 +1718,6 @@ void GenStackFuncBags ( void )
 
 UInt FullBags;
 
-#ifdef  DEBUG_DEADSONS_BAGS
-Bag OldMarkedBags;
-#endif
-
 /*  These are used to overwrite masterpointers which may still be
 linked from weak pointer objects but whose bag bodies have been
 collected.  Two values are used so that old masterpointers of this
@@ -1752,9 +1748,6 @@ UInt CollectBags (
 
     /*     Bag *               last;
            Char                type; */
-#ifdef DEBUG_DEADSONS_BAGS
-    UInt                pos;
-#endif
 
 #ifdef DEBUG_MASTERPOINTERS
     CheckMasterPointers();
@@ -1835,43 +1828,6 @@ again:
             MARK_BAG(first);
     }
 
-#ifdef  DEBUG_DEADSONS_BAGS
-    /* check for old bags pointing to new unmarked bags                    */
-    p = OldBags;
-    OldMarkedBags = MarkedBags;
-    while ( p < YoungBags ) {
-        if ( (*(UInt*)p & 0xFFL) == 255 ) {
-          if ((*(UInt*)p >> 16) == 1) 
-            p++;
-          else
-            p += 1 + WORDS_BAG( *(((UInt *)p)+1) );
-                
-        }
-        else {
-            (*TabMarkFuncBags[TNUM_BAG(p[2])])( p[2] );
-            pos = 0;
-            while ( MarkedBags != OldMarkedBags ) {
-                Pr( "#W  Old bag (type %s, size %d, ",
-                    (Int)InfoBags[ TNUM_BAG(p[2]) ].name,
-                    (Int)SIZE_BAG(p[2]) );
-                Pr( "handle %d, pos %d) points to\n",
-                    (Int)p[2],
-                    (Int)pos );
-                Pr( "#W    new bag (type %s, size %d, ",
-                    (Int)InfoBags[ TNUM_BAG(MarkedBags) ].name,
-                    (Int)SIZE_BAG(MarkedBags) );
-                Pr( "handle %d)\n",
-                    (Int)MarkedBags,
-                    (Int)0 );
-                pos++;
-                first = PTR_BAG(MarkedBags)[-1];
-                PTR_BAG(MarkedBags)[-1] = MarkedBags;
-                MarkedBags = first;
-            }
-            p += 3 + WORDS_BAG( ((UInt*)p)[1] );
-        }
-    }
-#endif
 
     /* tag all marked bags and mark their subbags                          */
     nrLiveBags = 0;
